svn commit: r278514 - stable/10/sys/netinet

Hans Petter Selasky hselasky at FreeBSD.org
Tue Feb 10 13:43:24 UTC 2015


Author: hselasky
Date: Tue Feb 10 13:43:23 2015
New Revision: 278514
URL: https://svnweb.freebsd.org/changeset/base/278514

Log:
  Append to the MFC of r278103 that we also pass along the M_FLOWID flag.
  
  Sponsored by:	Mellanox Technologies

Modified:
  stable/10/sys/netinet/ip_output.c

Modified: stable/10/sys/netinet/ip_output.c
==============================================================================
--- stable/10/sys/netinet/ip_output.c	Tue Feb 10 13:36:37 2015	(r278513)
+++ stable/10/sys/netinet/ip_output.c	Tue Feb 10 13:43:23 2015	(r278514)
@@ -801,8 +801,8 @@ smart_frag_failure:
 		/* make sure the flowid is the same for the fragmented mbufs */
 		M_HASHTYPE_SET(m, M_HASHTYPE_GET(m0));
 		m->m_pkthdr.flowid = m0->m_pkthdr.flowid;
-		/* copy multicast flag, if any */
-		m->m_flags |= (m0->m_flags & M_MCAST);
+		/* copy multicast and flowid flags, if any */
+		m->m_flags |= (m0->m_flags & (M_MCAST | M_FLOWID));
 		/*
 		 * In the first mbuf, leave room for the link header, then
 		 * copy the original IP header including options. The payload


More information about the svn-src-stable mailing list